@@ -6,15 +6,15 @@ class DmsClientError(JsonRESTError):
 
 
 class ResourceNotFoundFault(DmsClientError):
-    def __init__(self, message):
+    def __init__(self, message: str):
         super().__init__("ResourceNotFoundFault", message)
 
 
 class InvalidResourceStateFault(DmsClientError):
-    def __init__(self, message):
+    def __init__(self, message: str):
         super().__init__("InvalidResourceStateFault", message)
 
 
 class ResourceAlreadyExistsFault(DmsClientError):
-    def __init__(self, message):
+    def __init__(self, message: str):
         super().__init__("ResourceAlreadyExistsFault", message)
