@@ -1,2 +1,2 @@
-def decapitalize(key):
+def decapitalize(key: str) -> str:
     return key[0].lower() + key[1:]
